﻿using FishFactoryContracts.BusinessLogicsContracts;
using FishFactoryContracts.SearchModels;
using Microsoft.Extensions.Logging;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace FishFactoryView
{
    public partial class FormSellCanneds : Form
    {
        private readonly ILogger _logger;
        private readonly ICannedLogic _logicCanned;
        private readonly IShopLogic _logicShop;
        public FormSellCanneds(ILogger<FormSellCanneds> logger, ICannedLogic logicCanned, IShopLogic logicShop)
        {
            InitializeComponent();
            _logger = logger;
            _logicCanned = logicCanned;
            _logicShop = logicShop;
        }

        private void buttonSave_Click(object sender, EventArgs e)
        {
            if (string.IsNullOrEmpty(textBoxCount.Text))
            {
                MessageBox.Show("Заполните поле 'Количество'", "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
            if (comboBoxCanneds.SelectedValue == null)
            {
                MessageBox.Show("Выберите консерву", "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
            _logger.LogInformation("Продажа консерв");
            try
            {
                var operationResult = _logicShop.SellCanneds(_logicCanned.ReadElement(new CannedSearchModel()
                {
                    Id = Convert.ToInt32(comboBoxCanneds.SelectedValue)
                })!, Convert.ToInt32(textBoxCount.Text));
                if (!operationResult)
                {
                    throw new Exception("Ошибка при продаже консерв. Дополнительная информация в логах.");
                }
                MessageBox.Show("Сохранение прошло успешно", "Сообщение", MessageBoxButtons.OK, MessageBoxIcon.Information);
                DialogResult = DialogResult.OK;
                Close();
            }
            catch (Exception ex)
            {
                _logger.LogError(ex, "Ошибка продажи консерв");
                MessageBox.Show(ex.Message, "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void buttonCancel_Click(object sender, EventArgs e)
        {
            DialogResult = DialogResult.Cancel;
            Close();
        }

        private void FormSellCanneds_Load(object sender, EventArgs e)
        {
            _logger.LogInformation("Загрузка списка консерв для продажи");
            try
            {
                var list = _logicCanned.ReadList(null);
                if (list != null)
                {
                    comboBoxCanneds.DisplayMember = "CannedName";
                    comboBoxCanneds.ValueMember = "Id";
                    comboBoxCanneds.DataSource = list;
                    comboBoxCanneds.SelectedItem = null;
                }
            }
            catch (Exception ex)
            {
                _logger.LogError(ex, "Ошибка загрузки списка консерв");
                MessageBox.Show(ex.Message, "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
    }
}
